{% load static %}

{% if offline_imports %}
    {# load from source #}
    <link rel="stylesheet" href="{% static 'reaction/css/style.min.css' %}">
    <script src="{% static 'reaction/js/jquery.min.js' %}"></script>
{% else %}
    {# load from url #}
    <script src="https://cdn.tailwindcss.com"></script>
    <script src="{% static 'reaction/tailwindcss/tailwind.config.js' %}"></script>
    <link rel="stylesheet" href="{% static 'reaction/tailwindcss/style.css' %}">
    <script src="https://code.jquery.com/jquery-3.6.1.min.js"></script>
{% endif %}